# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-14 13:30


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('segments', '0011_remove_basesegment_sort'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='pagesort',
            options={'ordering': ['sort'], 'verbose_name': 'Page Sort', 'verbose_name_plural': 'Pages Sort'},
        ),
        migrations.AlterModelOptions(
            name='segmentsort',
            options={'ordering': ['sort'], 'verbose_name': 'Segment Sort', 'verbose_name_plural': 'Segments Sort'},
        ),
    ]
