# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-30 20:25


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('products', '0008_product_further_details'),
    ]

    operations = [
        migrations.AddField(
            model_name='product',
            name='aparnik_bon_return_expire_value',
            field=models.PositiveIntegerField(default=0, help_text='If the number is set to 0, then the value in the settings will apply', verbose_name='Bon Return Expire ( Hours )'),
        ),
        migrations.AddField(
            model_name='product',
            name='aparnik_bon_return_value',
            field=models.PositiveIntegerField(default=0, help_text='If the number is set to 0, then the value in the settings will apply', verbose_name='Bon Return'),
        ),
        migrations.AddField(
            model_name='product',
            name='has_permit_use_aparnik_bon_value',
            field=models.NullBooleanField(help_text='If the number is set to 0, then the value in the settings will apply', verbose_name='Has permit use aparnik bon'),
        ),
    ]
