# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-11 16:40


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('socials', '0004_auto_20181203_1328'),
    ]

    operations = [
        migrations.AddField(
            model_name='socialnetwork',
            name='value',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Value'),
        ),
    ]
