# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-25 10:57


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('settings', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='setting',
            name='is_variable_in_home',
            field=models.BooleanField(default=False, verbose_name='Is variable show in home'),
        ),
        migrations.AlterField(
            model_name='setting',
            name='value_type',
            field=models.CharField(choices=[('s', 'String'), ('i', 'Int'), ('b', 'Boolean'), ('dt', 'Date Time'), ('fr', 'Function setting return value')], max_length=31, verbose_name='Value Type'),
        ),
    ]
