# Generated by Django 2.2 on 2019-06-15 14:30

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('orders', '0011_auto_20190428_1107'),
    ]

    operations = [
        migrations.AlterField(
            model_name='orderitem',
            name='product_obj',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='orderitem_set', to='products.Product', verbose_name='Product'),
        ),
    ]
