# Generated by Django 2.2 on 2019-06-26 15:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('reviews', '0011_auto_20190626_1555'),
    ]

    operations = [
        migrations.RenameField(
            model_name='review',
            old_name='user_obj_2',
            new_name='user_obj',
        ),
    ]
