# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-14 15:37


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('basemodels', '0009_basemodel_sort'),
    ]

    operations = [
        migrations.AddField(
            model_name='basemodel',
            name='visit_count',
            field=models.IntegerField(default=0, verbose_name='Visit counter'),
        ),
    ]
