# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-03-19 17:44


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('products', '0016_product_is_draft'),
    ]

    operations = [
        migrations.AlterField(
            model_name='product',
            name='is_draft',
            field=models.BooleanField(default=False, verbose_name='Is draft'),
        ),
    ]
