# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-26 11:31


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('books', '0002_auto_20181025_1543'),
    ]

    operations = [
        migrations.AlterField(
            model_name='book',
            name='translators_obj',
            field=models.ManyToManyField(blank=True, related_name='library_translators', to='books.WriterTranslator', verbose_name='Translators'),
        ),
    ]
