# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-25 16:02


from django.db import migrations, models
import django.db.models.deletion
import django.core.validators
from aparnik.utils import fields


class Migration(migrations.Migration):

    dependencies = [
        ('filefields', '0001_initial'),
        ('aparnik_users', '0005_auto_20181025_1601'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='avatar',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='filefields.FileField', verbose_name='Avatar'),
        ),
    ]
