# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-21 18:56


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('orders', '0005_auto_20190120_1724'),
    ]

    operations = [
        migrations.AddField(
            model_name='order',
            name='uuid',
            field=models.UUIDField(blank=True, editable=False, null=True, verbose_name='Reference ID'),
        ),
    ]
