# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-20 17:24


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('orders', '0004_orderitem_is_tax'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='orderitem',
            options={'ordering': ('created_at',), 'verbose_name': 'OrderItem', 'verbose_name_plural': 'OrderItems'},
        ),
    ]
