# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-01 14:21


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('filefields', '0004_filefield_title'),
        ('files', '0003_remove_file_is_preview'),
    ]

    operations = [
        migrations.AddField(
            model_name='file',
            name='cover',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='shop_file_cover', to='filefields.FileField', verbose_name='\\u062a\\u0635\\u0648\\u06cc\\u0631 \\u062c\\u0644\\u062f'),
        ),
    ]
