# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-29 17:28


import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('vouchers', '0003_auto_20190129_1620'),
    ]

    operations = [
        migrations.AlterField(
            model_name='voucher',
            name='expire_at',
            field=models.DateTimeField(default=datetime.datetime(2219, 1, 29, 17, 28, 5, 432761), verbose_name='Expire at'),
        ),
    ]
