# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-17 20:56


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('products', '0013_product_currency'),
    ]

    operations = [
        migrations.AddField(
            model_name='product',
            name='is_tax',
            field=models.BooleanField(default=False, verbose_name='Is tax?'),
        ),
    ]
