# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-13 16:11


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('segments', '0004_auto_20181213_1607'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='basesegment',
            name='model_obj',
        ),
    ]
