# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-04-28 11:07


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('orders', '0010_order_postal_cost_value'),
    ]

    operations = [
        migrations.AddField(
            model_name='order',
            name='is_sync_with_websites',
            field=models.BooleanField(default=False, verbose_name='Is sync with websites'),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('w', 'Waiting'), ('pa', 'Paid'), ('paw', 'Paid by website'), ('c', 'Cancel'), ('co', 'Complete'), ('d', 'Disputed'), ('ch', 'Challenged')], default='w', max_length=5, verbose_name='Status'),
        ),
    ]
