# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-28 21:16


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sliders', '0002_slidersegment'),
        ('teachers', '0002_auto_20181026_1301'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='teacher',
            name='slider_obj',
        ),
        migrations.AddField(
            model_name='teacher',
            name='slider_segment_obj',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='sliders.SliderSegment', verbose_name='Slider Semgent'),
        ),
    ]
