# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-22 21:08


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('orders', '0008_auto_20190121_2101'),
    ]

    operations = [
        migrations.AddField(
            model_name='orderitem',
            name='description',
            field=models.TextField(blank=True, default='', null=True, verbose_name='Description'),
        ),
    ]
