# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-05-01 11:42


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('filefields', '0005_auto_20190501_1142'),
    ]

    operations = [
        migrations.AlterField(
            model_name='filefield',
            name='is_lock',
            field=models.BooleanField(default=True, verbose_name='Is lock?'),
        ),
    ]
