# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-25 15:43


from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('shortblogs', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='TermsAndConditions',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.BooleanField(default=True, verbose_name='Is Active')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('update_at', models.DateTimeField(auto_now=True, verbose_name='Update at')),
                ('short_blogs', models.ManyToManyField(to='shortblogs.ShortBlog', verbose_name='Content Segment')),
            ],
            options={
                'verbose_name': 'Terms And Conditions',
                'verbose_name_plural': 'Terms And Conditions',
            },
        ),
    ]
