# Generated by Django 2.2 on 2019-06-26 15:55

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('questionanswers', '0010_auto_20190626_1549'),
        ('reviews', '0010_auto_20190626_1549'),
    ]

    operations = [
        migrations.AlterField(
            model_name='qa',
            name='user_obj_2',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='کاربر'),
            preserve_default=False,
        ),
    ]
