# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-10 14:42


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('categories', '0003_remove_category_pages'),
        ('news', '0002_auto_20181209_2322'),
    ]

    operations = [
        migrations.AddField(
            model_name='news',
            name='categories',
            field=models.ManyToManyField(to='categories.Category', verbose_name='\\u062f\\u0633\\u062a\\u0647 \\u0628\\u0646\\u062f\\u06cc \\u0647\\u0627'),
        ),
    ]
