# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-26 17:45


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aparnik_users', '0007_auto_20181025_1602'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='devicelogin',
            options={'verbose_name': 'Device Login', 'verbose_name_plural': 'Devices Login'},
        ),
    ]
